macro.profileDescPart

Groups elements that capture a portion of a bibliographic description.
Module
Contained By
(MEI.shared) Groups elements that capture a portion of a bibliographic description.
<biblFull>Contains a structured bibliographic description in which many, but not all, components must appear in a specified order.
<biblFull>Contains a structured bibliographic description in which many, but not all, components must appear in a specified order.
May Contain
(MEI.shared) Groups elements that capture a portion of a bibliographic description.
<audience>Defines the class of user for which the work is intended, as defined by age group (e.g., children, young adults, adults, etc.), educational level (e.g., primary, secondary, etc.), or other categorization.
<classification>Groups information which describes the nature or topic of an entity.
<contents>List of the material contained within a resource.
<context>The historical, social, intellectual, artistic, or other context within which the work was originally conceived (e.g., the 17th century restoration of the monarchy in England, the aesthetic movement of the late 19th century, etc.) or the historical, social, intellectual, artistic, or other context within which the expression was realized.
<creation>Non-bibliographic details of the creation of an intellectual entity, in narrative form, such as the date, place, and circumstances of its composition. More detailed information may be captured within the history element.
<dedication>Contains a dedicatory statement.
<history>Provides a container for information about the history of a resource other than the circumstances of its creation.
<langUsage>Groups elements describing the languages, sub-languages, dialects, etc., represented within the encoded resource.
<otherChar>Any characteristic that serves to differentiate a work or expression from another.
<perfDuration>Used to express the duration of performance of printed or manuscript music or the playing time for a sound recording, videorecording, etc.
<perfMedium>Indicates the number and character of the performing forces used in a musical composition.
<audience>Defines the class of user for which the work is intended, as defined by age group (e.g., children, young adults, adults, etc.), educational level (e.g., primary, secondary, etc.), or other categorization.
<classification>Groups information which describes the nature or topic of an entity.
<contents>List of the material contained within a resource.
<context>The historical, social, intellectual, artistic, or other context within which the work was originally conceived (e.g., the 17th century restoration of the monarchy in England, the aesthetic movement of the late 19th century, etc.) or the historical, social, intellectual, artistic, or other context within which the expression was realized.
<dedication>Contains a dedicatory statement.
<history>Provides a container for information about the history of a resource other than the circumstances of its creation.
<langUsage>Groups elements describing the languages, sub-languages, dialects, etc., represented within the encoded resource.
<otherChar>Any characteristic that serves to differentiate a work or expression from another.
<perfDuration>Used to express the duration of performance of printed or manuscript music or the playing time for a sound recording, videorecording, etc.
<perfMedium>Indicates the number and character of the performing forces used in a musical composition.
<creation>Non-bibliographic details of the creation of an intellectual entity, in narrative form, such as the date, place, and circumstances of its composition. More detailed information may be captured within the history element.
Declaration
<macroSpec xmlns="http://www.tei-c.org/ns/1.0" rend="add" ident="macro.profileDescPart" module="MEI.shared" type="pe">
<desc xml:lang="en">Groups elements that capture a portion of a bibliographic description.</desc>
<content>
<rng:interleave>
<optional>
<ref name="audience"/>
</optional>
<optional>
<ref name="classification"/>
</optional>
<optional>
<ref name="contents"/>
</optional>
<optional>
<ref name="context"/>
</optional>
<optional>
<ref name="creation"/>
</optional>
<optional>
<ref name="dedication"/>
</optional>
<optional>
<ref name="history"/>
</optional>
<optional>
<ref name="langUsage"/>
</optional>
<optional>
<ref name="otherChar"/>
</optional>
<optional>
<ref name="perfDuration"/>
</optional>
<optional>
<ref name="perfMedium"/>
</optional>
</rng:interleave>
</content>
</macroSpec>