(MEI.header) Content model for elements that can be used to describe historical account.
<eventList>Contains historical information given as a sequence of significant past events.
(MEI.shared) Groups elements used to provide a heading at the start of a text division
or other markup component.
<head>Contains any heading, for example, the title of a section of text, or the
heading of a list.
(MEI.shared) Groups paragraph-like elements.
<p>One or more text phrases that form a logical prose passage.
(MEI.shared) Groups textual elements that occur at the level of individual words or
phrases. This class is equivalent to the model.textPhraseLike class without the pb
element.
(MEI.msDesc) Groups elements that may appear inline when the msdesc module is active.
<catchwords>Describes the system used to ensure correct ordering of the quires making up an item,
typically by means of annotations at the foot of the page.
<heraldry>Contains a heraldic formula or phrase, typically found as part of a blazon, coat of
arms,
etc.
<locus>Defines a location within a manuscript or manuscript component, usually as a (possibly
discontinuous) sequence of folio references.
<locusGrp>Groups locations which together form a distinct but discontinuous item
within a manuscript or manuscript part, according to a specific foliation.
<secFolio>Marks the word or words taken from a fixed point in a codex (typically
the beginning of the second leaf) in order to provide a unique identifier for the
item.
<signatures>Provides a description of the leaf or quire signatures found within a codex.
<stamp>Contains a word or phrase describing an official mark indicating ownership, genuineness,
validity, etc.
(MEI.namesdates) Groups elements used as part of a physical address.
<postBox>Contains a number or other identifier for some postal
delivery point other than a street address.
<postCode>Contains a numerical or alphanumeric code used as part of a postal address
to simplify sorting or delivery of mail.
<street>full street address including any name or number identifying a building as well as
the
name of the street or route on which it is located.
(MEI.namesdates) Groups elements which form part of a geographic name.
<bloc>Contains the name of a geopolitical unit consisting of two or more nation states or
countries.
<country>Contains the name of a geopolitical unit, such as a nation, country, colony, or
commonwealth, larger than or administratively superior to a region and smaller than
a
bloc.
<district>Contains the name of any kind of subdivision of a settlement, such as a parish, ward,
or
other administrative or geographic unit.
<geogFeat>Contains a common noun identifying a geographical
feature.
<region>Contains the name of an administrative unit such as a state, province, or county,
larger
than a settlement, but smaller than a country.
<settlement>Contains the name of a settlement such as a city, town, or village identified as a
single
geopolitical or administrative unit.
(MEI.namesdates) Groups elements which contain names of individuals or corporate bodies.
<corpName>Identifies an organization or group of people that acts as a single
entity.
<persName>Designation for an individual, including any or all of that individual's
forenames, surnames, honorific titles, and added names.
(MEI.namesdates) Groups elements that serve as stylistic labels.
<periodName>A label that describes a period of time, such as 'Baroque' or '3rd Style
period'.
<styleName>A label for a characteristic style of writing or performance, such as
'bebop' or 'rock-n-roll'.
(MEI.namesdates) Groups place name elements.
(MEI.namesdates) Groups geographic name elements.
<geogName>The proper noun designation for a place, natural feature, or political
jurisdiction.
(MEI.shared) Groups elements that denote a corporate entity that holds a bibliographic
item.
<repository>Institution, agency, or individual which holds a bibliographic item.
(MEI.shared) Groups elements which describe a measurement forming part of the physical
dimensions of an object.
<depth>Description of a measurement taken through a three-dimensional object.
<titlePart>Contains a subsection or division of the title of a bibliographic entity.
(MEI.text) Groups elements related to highlighting which can appear at the phrase-level.
<q>Contains material which is distinguished from the surrounding phrase-level text
using quotation marks or a similar method. Use <quote> for block-level
quotations.
textual content
<abbr>A generic element for 1) a shortened form of a word, including an acronym
or 2) a shorthand notation.
<fig>Groups elements representing or containing graphic information such as an
illustration or figure.
<catchwords>Describes the system used to ensure correct ordering of the quires making up an item,
typically by means of annotations at the foot of the page.
<heraldry>Contains a heraldic formula or phrase, typically found as part of a blazon, coat of
arms,
etc.
<locus>Defines a location within a manuscript or manuscript component, usually as a (possibly
discontinuous) sequence of folio references.
<locusGrp>Groups locations which together form a distinct but discontinuous item
within a manuscript or manuscript part, according to a specific foliation.
<secFolio>Marks the word or words taken from a fixed point in a codex (typically
the beginning of the second leaf) in order to provide a unique identifier for the
item.
<signatures>Provides a description of the leaf or quire signatures found within a codex.
<stamp>Contains a word or phrase describing an official mark indicating ownership, genuineness,
validity, etc.
<bloc>Contains the name of a geopolitical unit consisting of two or more nation states or
countries.
<corpName>Identifies an organization or group of people that acts as a single
entity.
<corpName>Identifies an organization or group of people that acts as a single
entity.
<country>Contains the name of a geopolitical unit, such as a nation, country, colony, or
commonwealth, larger than or administratively superior to a region and smaller than
a
bloc.
<district>Contains the name of any kind of subdivision of a settlement, such as a parish, ward,
or
other administrative or geographic unit.
<geogFeat>Contains a common noun identifying a geographical
feature.
<geogName>The proper noun designation for a place, natural feature, or political
jurisdiction.
<geogName>The proper noun designation for a place, natural feature, or political
jurisdiction.
<periodName>A label that describes a period of time, such as 'Baroque' or '3rd Style
period'.
<periodName>A label that describes a period of time, such as 'Baroque' or '3rd Style
period'.
<persName>Designation for an individual, including any or all of that individual's
forenames, surnames, honorific titles, and added names.
<persName>Designation for an individual, including any or all of that individual's
forenames, surnames, honorific titles, and added names.
<postBox>Contains a number or other identifier for some postal
delivery point other than a street address.
<postCode>Contains a numerical or alphanumeric code used as part of a postal address
to simplify sorting or delivery of mail.
<region>Contains the name of an administrative unit such as a state, province, or county,
larger
than a settlement, but smaller than a country.
<settlement>Contains the name of a settlement such as a city, town, or village identified as a
single
geopolitical or administrative unit.
<street>full street address including any name or number identifying a building as well as
the
name of the street or route on which it is located.
<styleName>A label for a characteristic style of writing or performance, such as
'bebop' or 'rock-n-roll'.
<styleName>A label for a characteristic style of writing or performance, such as
'bebop' or 'rock-n-roll'.
<ptr>Defines a traversible pointer to another location, using only attributes to
describe the destination.
<ref>Defines a traversible reference to another location. May contain text and
sub-elements that describe the destination.
<address>Contains a postal address, for example of a publisher, an organization, or an
individual.
<annot>Associates a statement or other information with a part of the encoding.
<bibl>Provides a loosely-structured bibliographic citation in which
the sub-components may or may not be explicitly marked.
<biblFull>Contains a structured bibliographic description in which many,
but not all, components must appear in a specified order.
<biblStruct>Contains a bibliographic citation in which
bibliographic sub-elements must appear in a specified order.
<date>A string identifying a point in time or the time period between two such points.
<depth>Description of a measurement taken through a three-dimensional object.
<titlePart>Contains a subsection or division of the title of a bibliographic entity.
<width>Description of the horizontal size of an object.
<q>Contains material which is distinguished from the surrounding phrase-level text
using quotation marks or a similar method. Use <quote> for block-level
quotations.
<seg>represents any segmentation of text below the "text component" level.